Module sphere

Module sphere 

Concrete implementations of the various subcommands of the sphere command

Functions

auth_add
Add an authorization for another device key (given by its Did) to the sphere
auth_list
List all authorizations in the sphere, optionally as a tree hierarchy representing the chain of authority, and optionally in JSON format
auth_revoke
Revoke an authorization for another device key by its nickname
config_get
Get a local metadata value from the database
config_set
Set a local metadata value in the database
follow_add
Add a peer to your address book by assigning their sphere ID to a nickname
follow_list
List all the entries in the address book, optionally in JSON format
follow_remove
Remove a peer to your address book either by nickname or by Did (but not both); if the removal is by Did, all petnames assigned to that Did will be removed.
follow_rename
Rename an entry in the sphere’s address book to something new
history
Print the available local history of the sphere to stdout
render
Render the workspace up to a specified maximum render depth
save
TODO(#105): We may want to change this to take an optional list of paths to consider, and allow the user to rely on their shell for glob filtering
sphere_create
Create a sphere, assigning authority to modify it to the given key (specified by nickname)
sphere_join
Join an existing sphere
status
Get the current status of the workspace, reporting the content that has changed in some way (if any)
sync
Attempt to synchronize the local workspace with a configured gateway, optionally automatically retrying a fixed number of times in case a rebase is required, and then re-rendering the workspace as needed up to a given depth.