save

Function save 

pub async fn save(
    render_depth: Option<u32>,
    workspace: &Workspace,
) -> Result<()>
TODO(#105): We may want to change this to take an optional list of paths to consider, and allow the user to rely on their shell for glob filtering