SphereDetails

Type Alias SphereDetails 

pub type SphereDetails = (Did, Link<MemoIpld>, Option<LinkRecord>);
Metadata about a given sphere, including the sphere ID, a Link to it and a corresponding LinkRecord (if one is available).