pub async fn auth_list(
tree: bool,
as_json: bool,
workspace: &Workspace,
) -> Result<()>Expand description
List all authorizations in the sphere, optionally as a tree hierarchy representing the chain of authority, and optionally in JSON format