pub async fn sync(
auto_retry: u32,
render_depth: Option<u32>,
workspace: &Workspace,
) -> Result<()>Expand description
Attempt to synchronize the local workspace with a configured gateway, optionally automatically retrying a fixed number of times in case a rebase is required, and then re-rendering the workspace as needed up to a given depth.