Operations that are common to most CLI commands
Structs
- Workspace
- The Workspace is the kernel of the CLI. It implements it keeps state and implements routines that are common to most CLI commands.
Type Aliases
- CliSphere
Context - The flavor of SphereContext used through the CLI
- Sphere
Details - Metadata about a given sphere, including the sphere ID, a Link to it and a corresponding LinkRecord (if one is available).