pub type SphereDetails = (Did, Link<MemoIpld>, Option<LinkRecord>);Expand description
Metadata about a given sphere, including the sphere ID, a Link to it and a corresponding LinkRecord (if one is available).
pub type SphereDetails = (Did, Link<MemoIpld>, Option<LinkRecord>);Metadata about a given sphere, including the sphere ID, a Link to it and a corresponding LinkRecord (if one is available).